﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using MindFusion.Scheduling;
using MindFusion.Scheduling.WebForms;

public partial class _Default : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            DateTime startDate = DateTime.Now;
            DateTime endDate = startDate.AddDays(7);

            while (startDate < endDate)
            {
                TimetableDate date = new TimetableDate(startDate);
                Calendar1.TimetableSettings.Dates.Add(date);
                startDate = startDate.AddDays(1);
            }

            CreateScheduleData();
        }
        else
        {
            if (Calendar2.Selection.Ranges.Count != 0)
            {
                Calendar1.TimetableSettings.Dates.Clear();
                DateTime startDate = Calendar2.Selection.Ranges[0];
                DateTime endDate = Calendar2.Selection.Ranges[1];
                while (startDate < endDate)
                {
                    TimetableDate date = new TimetableDate(startDate);
                    Calendar1.TimetableSettings.Dates.Add(date);
                    startDate = startDate.AddDays(1);
                }
            }
        }
    }

    private void CreateScheduleData()
    {
        //create some contacts
        Contact contact1 = new Contact();
        contact1.FirstName = "James";
        contact1.LastName = "Jones";
        Calendar1.Schedule.Contacts.Add(contact1);

        Contact contact2 = new Contact();
        contact2.FirstName = "Mary";
        contact2.LastName = "Brown";
        Calendar1.Schedule.Contacts.Add(contact2);

        //create some locations
        Location location1 = new Location();
        location1.City = "London";
        location1.Name = "London";
        Calendar1.Schedule.Locations.Add(location1);

        Location location2 = new Location();
        location2.City = "Paris";
        location2.Name = "Paris";
        Calendar1.Schedule.Locations.Add(location2);

        //create some events
        Appointment app1 = new Appointment();
        app1.StartTime = DateTime.Now.AddMinutes(16);
        app1.EndTime = app1.StartTime.AddHours(2);
        app1.EndTime = app1.StartTime.AddHours(2);
        app1.Subject = "Meeting";
        app1.DescriptionText = "I really must be there on time";
        app1.Locked = true;
        app1.Location = location1;
        app1.Contacts.Add(contact1);
        Calendar1.Schedule.Items.Add(app1);

        Appointment app2 = new Appointment();
        app2.StartTime = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 13, 0, 0);
        app2.EndTime = app2.StartTime.AddHours(1);
        app2.Subject = "Lunch";
        app2.DescriptionText = "Yummy!";
        app2.Location = location1;
        app2.Contacts.Add(contact1);
        Calendar1.Schedule.Items.Add(app2);

        Appointment app3 = new Appointment();
        app3.StartTime = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 7, 30, 0);
        app3.EndTime = app3.StartTime.AddHours(3);
        app3.Subject = "Yoga class";
        app3.DescriptionText = "Yeah!";
        app3.Location = location2;
        app3.Contacts.Add(contact2);
        Calendar1.Schedule.Items.Add(app3);

        Appointment app4 = new Appointment();
        app4.StartTime = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 20, 0, 0);
        app4.EndTime = app4.StartTime.AddHours(1);
        app4.Subject = "Dinner";
        app4.DescriptionText = "with the family";
        app4.Location = location2;
        app4.Contacts.Add(contact2);
        Calendar1.Schedule.Items.Add(app4);

        Recurrence recurrence1 = new Recurrence()
        {
            Pattern = RecurrencePattern.Daily,
            DailyRecurrence = DailyRecurrence.EveryWorkday,
            StartDate = app2.StartTime,
            RecurrenceEnd = RecurrenceEnd.EndDate,
            EndDate = new DateTime(2011, 12, 31)
        };
        app2.Recurrence = recurrence1;

        Recurrence recurrence2 = new Recurrence()
        {
            Pattern = RecurrencePattern.Weekly,
            DaysOfWeek = DaysOfWeek.Monday | DaysOfWeek.Wednesday,
            StartDate = app3.StartTime,
            NumOccurrences = 30
        };
        app3.Recurrence = recurrence2;

        Reminder reminder = new Reminder();
        reminder.Message = "Get ready for the very important meeting!";
        reminder.Type = ReminderType.Leading;
        reminder.TimeInterval = TimeSpan.FromMinutes(15);
        app1.Reminder = reminder;

        //fill the list of contacts
        lbContacts.Items.Clear();
        lbContacts.Items.Add(new ListItem(contact1.LastName + ", " + contact1.FirstName));
        lbContacts.Items.Add(new ListItem(contact2.LastName + ", " + contact2.FirstName));
        lbContacts.Items[0].Selected = true;

    }

    protected void Button1_Click(object sender, EventArgs e)
    {
        Calendar1.Contacts.Clear();
        if (lbContacts.SelectedIndex != -1)
        {
            // Filter by selected contacts
            for (int i = 0; i < lbContacts.Items.Count; i++)
            {
                var li = lbContacts.Items[i];
                if (li.Selected)
                {
                    Contact c = Calendar1.Schedule.Contacts[i];
                    if (!Calendar1.Contacts.Contains(c))
                        Calendar1.Contacts.Add(c);
                }
            }
            Calendar1.GroupType = GroupType.FilterByContacts;
        }
    }
    protected void Button2_Click(object sender, EventArgs e)
    {
        Calendar1.Contacts.Clear();
        if (lbContacts.SelectedIndex != -1)
        {
            // Group by selected contacts
            for (int i = 0; i < lbContacts.Items.Count; i++)
            {
                var li = lbContacts.Items[i];
                if (li.Selected)
                {
                    Contact c = Calendar1.Schedule.Contacts[i];
                    if (!Calendar1.Contacts.Contains(c))
                        Calendar1.Contacts.Add(c);
                }
            }
            Calendar1.GroupType = GroupType.GroupByContacts;
        }
    }
    protected void Button3_Click(object sender, EventArgs e)
    {
        Calendar1.Contacts.Clear();
        Calendar1.GroupType = GroupType.None;
    }
}
